==> v1.0.12.zip: og-steam/README.md <==
# OG-Steam

Update: Try <a href="https://github.com/ungstein/OG-Steam-Library">OG-Steam-Library<a> theme for use with <a href="https://github.com/PhantomGamers/SteamFriendsPatcher">SteamFriendsPatcher<a>.

An Internet Time Warp
-

Steam, in its current form, is hardly recognisable when compared to early releases. However, you may be surprised to learn that, despite innumerable changes made to Steam in its 17-year lifespan, its Graphical User Interface system, VGUI (which is built into the Source engine), has remained virtually unchanged. This has allowed me to create a skin which very accurately replicates the look and feel of the Steam client from around 2004. I have future-proofed this skin to the best of my ability by including as few files as possible (and, therefore, fewer points of failure). Ostensibly, Valve has plans to re-write the Steam client in JavaScript; we have already seen several moves in this direction. Until such time, welcome to 2004.

This version has been tested on Windows running the latest version of the Steam client (**As at 2021-07-11**).

Installing
-

**Note: This skin has not been tested on Linux or MacOS**

* Copy **OG-Steam** into `Steam/skins`
* Select the new skin through `Settings/Interface`
* Install the <a href="https://github.com/ungstein/OG-Steam/files/7207148/WineTahomaBit.zip">WineTahomaBit</a> font for a truly authentic retro look
  (Credit: <a href="https://github.com/Xenthio">Xenthio</a>, based on "Wine Tahoma Regular" Version 0.001 (C) 2004 Larry Snyder Based on Bitstream Vera Sans (C) Bitstream Inc GNU Lesser General Public License 2.1).

  WineTahomaBit is enabled by changing basefont from "Tahoma" to "WineTahomaBit" on line 36 of "OG-Steam\resource\styles\steam.styles". This will be enabled by default with the next release. Note: DirectWrite **must be disabled** through `Settings/Interface`, or characters will be invisible.

Preview
-

![Login](https://i.imgur.com/FdG0g2M.png)
![About Steam](https://i.imgur.com/0zAdg0c.png)
![VGUI Zoo](https://i.imgur.com/deMlNiK.png)
![Store](https://i.imgur.com/mE7buzK.png)
![Library](https://i.imgur.com/xZaufv7.png)
![Downloads](https://i.imgur.com/XrAaI2J.png)
![Small Mode](https://i.imgur.com/HSO8YJb.png)
![Overlay](https://i.imgur.com/21kRSmh.png)
![Servers](https://i.imgur.com/CFMBKd7.png)
![Music Player](https://i.imgur.com/0ojNCTZ.png)

==> v1.0.13a.zip: og-steam/README.md <==
# OG-Steam

Update: Try <a href="https://github.com/ungstein/OG-Steam-Library">OG-Steam-Library<a> theme for use with <a href="https://github.com/PhantomGamers/SFP">SFP</a> (Previously <a href="https://github.com/PhantomGamers/SteamFriendsPatcher">SteamFriendsPatcher<a>).

An Internet Time Warp
-

Steam, in its current form, is hardly recognisable when compared to early releases. However, you may be surprised to learn that, despite innumerable changes made to Steam in its 17-year lifespan, its Graphical User Interface system, VGUI (which is built into the Source engine), has remained virtually unchanged. This has allowed me to create a skin which very accurately replicates the look and feel of the Steam client from around 2004. I have future-proofed this skin to the best of my ability by including as few files as possible (and, therefore, fewer points of failure). Ostensibly, Valve has plans to re-write the Steam client in JavaScript; we have already seen several moves in this direction. Until such time, welcome to 2004.

This version has been tested on Windows running the latest version of the Steam client (**As at 2022-05-13**).

Installing
-

**Note: This skin has not been tested on Linux or MacOS**

* Copy the **OG-Steam** folder into `Steam/skins`
* Select the new skin through `Settings/Interface`
* Install the <a href="https://github.com/ungstein/OG-Steam/files/7207148/WineTahomaBit.zip">WineTahomaBit</a> font for a truly authentic retro look
  (Credit: <a href="https://github.com/Xenthio">Xenthio</a>, based on "Wine Tahoma Regular" Version 0.001 (C) 2004 Larry Snyder Based on Bitstream Vera Sans (C) Bitstream Inc GNU Lesser General Public License 2.1).

  WineTahomaBit is enabled by changing basefont from "Tahoma" to "WineTahomaBit" on line 36 of "OG-Steam\resource\styles\steam.styles". This will be enabled by default with the next release. Note: DirectWrite **must be disabled** through `Settings/Interface`, or characters will be invisible.

Preview
-

![Login](https://i.imgur.com/FdG0g2M.png)
![About Steam](https://i.imgur.com/0zAdg0c.png)
![VGUI Zoo](https://i.imgur.com/deMlNiK.png)
![Store](https://i.imgur.com/mE7buzK.png)
![Library](https://i.imgur.com/xZaufv7.png)
![Downloads](https://i.imgur.com/XrAaI2J.png)
![Small Mode](https://i.imgur.com/HSO8YJb.png)
![Overlay](https://i.imgur.com/21kRSmh.png)
![Servers](https://i.imgur.com/CFMBKd7.png)
![Music Player](https://i.imgur.com/0ojNCTZ.png)
